{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "%pylab inline\n",
    "from tvb.simulator.lab import *"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Having multiple stimuli with different time courses for different nodes currently requires an extra class, see usage below"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "class MultiStimuliRegion(patterns.StimuliRegion):\n",
    "    def __init__(self, *stimuli):\n",
    "        self.stimuli = stimuli\n",
    "    def configure_space(self, *args, **kwds):\n",
    "        [stim.configure_space(*args, **kwds) for stim in self.stimuli]\n",
    "    def configure_time(self, *args, **kwds):\n",
    "        [stim.configure_time(*args, **kwds) for stim in self.stimuli]\n",
    "    def __call__(self, *args, **kwds):\n",
    "        return np.array([stim(*args, **kwds) for stim in self.stimuli]).sum(axis=0)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Now we can make several pulse trains with different temporal configurations and node weights, and combine them with above class."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "<matplotlib.colorbar.Colorbar at 0x10dd65190>"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAWkAAAEFCAYAAAAhTRZvAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAHxtJREFUeJzt3X2UHVWZ7/HvLwmgSEAYJCGN0IIQvK4LgTGAgyPhRXlR\ngZm5CwUv8rIcnHtBWINrFJzlS1xyhbscHRXmahzMRC6IDCxN4KJEJraICoaXSORdMAG6SWNEWQMI\n5OW5f1Q1qe70Oaf6nFN1qrp/n7Vq5VSdXXs/dTrr6ep9du2tiMDMzKppWq8DMDOzxpykzcwqzEna\nzKzCnKTNzCrMSdrMrMKcpM3MKsxJ2sysCyTtIWmFpPslrZZ0foNyX5X0qKRVkua1qndG90M1M5uS\nNgIXRsQqSTsAd0taHhEPjRSQdDywT0TsK+lQ4OvAYc0q9Z20mVkXRMS6iFiVvn4eeBDoG1PsJODb\naZk7gZ0kzWpWr5O0mVmXSeoH5gF3jnmrD3gysz/I1ol8FHd3mJmlXi/Fc/mLD0fE7LEH066O64EL\n0jvqjjhJm5mlngM+m7PsZ2GrbgpJM0gS9FURsXSc0waBN2b290iPNeTuDjOzjBk5twa+BTwQEV9p\n8P4y4EMAkg4D/hgRw63iMTOz1DZtnifpcOCDwGpJ9wIBfBLYC4iIWBQRN0s6QdJvgBeAs1rV6yRt\nZpbx2jbPi4ifAdNzlDtvIvU6SZuZZVQtKVYtHjOznmq3u6MoPfviUNJxkh6S9IikT/QqDjOzrA6/\nOCwkntJJmgZcDhwNDAErJS3NPj5pZtYLVbuT7lV3xyHAoxGxFkDStSSPSzpJm1lPVa0PuFfxjH00\n8imSxD2KJK+Sa2a5RYQ6rcN30hN2BLCg10EUYIDJd10DTL5rAl9X9c2fP4eVKz/SlbraHYJXlF4l\n6UFgz8x+k0cj15D8ZwLoTzczszXpBoODM7tWq++kEyuBN0vaC3ga+ABw6vhF+5ksv+3NrJv6Gblp\n6+ubw9DQTV2ptWrdCz2JJyI2SToPWE4yDPDKiHhw/NL95QVWqv5eB1CA/l4HUJD+XgdQkP5eB1BJ\nvpNORcQPgbmtS/YXHUqP9Pc6gAL09zqAgvT3OoCC9Pc6gErynbSZWYX5TtrMrMI8usPMrMKqlhQ9\n6b+ZWcY2ObfxSLpS0rCk+xq8v6OkZZJWSVot6cxW8ThJm5lldJKkgcXAsU2qPxe4PyLmAUcC/5Qu\nudVQ1e7szcx6qpOkGBG3p89/NCwCjDx5MxP4fURsLCoeM7NJZ5u8WbFpam3ocmCZpCFgB+D9rU5w\nkjYzy5jRICv+dBPcvrnj6o8F7o2IoyTtA/xI0gER8XzDeDpu0sxsEnntduMff3e6jbj0ubaqPwv4\nAkBEPCbpt8D+wF2NTnCSNjPLyN3d0ZjSbTxrgWOAn0maBewHPN6sMidpM7Oslut9NybpGpIZ4f5M\n0hPAZ4BtgYiIRcDngX/LDNH7eEQ826xOJ2kzs6wOsmJEnNbi/adpPkSvm+GYmU1CFcuKFQunmb8f\n59iXSzpnsrZV9fjKbKvu8ZXZVh0+iw5ULCtWLBwzsx7roE+6CE7SZmZZr+l1AKMporoLcierhX+m\n12GYWcWNLETb6WrhkpJZNfKUXdWd1clb8Z20mVlWxbJiobPgjTdtn6SdJS2X9LCkWyTtVGQMZmYT\nMiPnVpKipyodb9q+i4BbI2IusAK4uOAYzMzym55zK0mhSToibgf+MObwScCS9PUS4OQiYzAzm5CK\n3Un3ovdlt4gYBoiIdZJ260EMVmtbvuz+x80bJnoKl0zfdsJt5W6n7bbauKYetdXO5zehttr+WXVJ\nxfqkqxBOi+ElA5nX/XgZejNLrEk3GByc2azgxDSYBa9XepGkhyXNiohhSbOBZ5oXX1BGTGZWO/2M\n3LT19c1haOim7lRbhVvXjDLCGTtt3zLgTOAy4AxgaQkx2KSy5b/TJdOarDbXxbbKasdtVUDFknTR\nQ/CuAX4O7CfpCUlnAZcC75L0MHB0um9mVg0djO5otVp4WmaBpHsl/VrSj1uFU+jvjCbT9h0z8dqm\nyuQxZbZV9fjynHdhl9pqp50y2ypqgqVufX5ltlXpCZYWA18Dvj3em+lzIVcA746IQUm7FhuOmdlk\n09l80q1WCz8NuCEiBtPy61vVWfTDLGZm9VLswyz7AbtI+rGklZJOb3WCJ1gys9rr6gRLfzf+ewOD\nMDC0ZX/h3eNPsJTeSd8YEQeM897XgD8HjgJeB/wCOCEiftMoJnd3mJllNciKC/ZKthEL726r9qeA\n9RHxEvCSpNuAA4GGSdrdHWZmWZ13dzRbLXwp8A5J0yVtDxwKPNisMt9Jm5lldZAVW60WHhEPSboF\nuA/YBCyKiAcKCsfMbBIqcLXwtMwXgS+WEI6Z2STkNQ7NzCqsYmscOkmbmWVVLCtWLBwzsx5zd4eZ\nWYVVLCtWLBwzsx6rWFasWDjNeOa37rdV9fjKbKvu8ZXZVh0+iw64u8PMrMIqlhU9wZKZ1V5XJ1ha\nnLPsWeNPsNRtFfudYWbWYxXLihULx8ysxyqWFYte43APSSsk3S9ptaTz0+M7S1ou6WFJt6RLypiZ\n9d6MnFtJip6qdCNwYUS8FXg7cK6k/YGLgFsjYi6wAri44DjMzPIpdmWWCSs0SUfEuohYlb5+nmTe\n1D2Ak4AlabElwMlFxmFmllsHd9J5VgtPy82XtEHSX+cJpxSS+oF5wB3ArIgYhiSRS9qtrDhsMtgy\nIukfN2+Y6ClcMn3bCbeVu52222rjmnrUVjuf34Taavtn1SUFrhYOIGkacClwS/Hh5CRpB+B64IKI\neD4ZWjdKk3GAA5nX/elmZrYm3WBwcGb3qt2u/VNzrBYO8FGSfDg/T52FJ2lJM0gCuioilqaHhyXN\niohhSbOBZxrXsKDoEK12tgxNvWTaNqW0VVY7bmsi+hm5aevrm8PQ0E3dqbbArChpDnByRBwp6ZAe\nh/OqbwEPRMRXMseWAWcClwFnkKz7ZWbWew2+FBy4Bwbu7bj2fwY+kdlv+TBMoUla0uHAB4HVku4l\n6db4JElyvk7S2cBa4JQi4zAzy63RauGHJNuIhTmfTBzjbcC1kgTsChwvaUNELJtgON0RET+j8WCV\nYyZW21SZPKbMtqoeX57zLuxSW+20U2ZbRU2w1K3Pr8y2Cp5gqfOs2HC18IjY+9VC0mLgxmYJujvh\nmJlNJgWuFj6meK6Jk5ykzcyyOnhQJc9q4ZmyZ+cp51nwzKz2ujoL3qM5y+7rWfDMzMrnSf/NzCqs\nYlmxYuGYmfVYxbJixcIxM+uximXFioVjZtZb4T5pM7Pq2lSxrFixcMzMeuvl7fJOs7+50DhGOEmb\nmWVsmpE3Lb5SaBwjnKTNzDI2Ta9Wp7STtJlZxqaKPc1SoyTtmd+631bV4yuzrbrHV2Zbdfgs2rfR\nSdrMrLo2VSwteoIlM6u9bk6w9Hjsnqvs3np6q/YkXQm8FxiOiAPGqf80tqzM8p/A/4iI1c3ayTvW\nxMxsStjE9FxbA4uBY5tU/zjwzog4EPg88M1W8VTrvt7MrMc66ZNutVp4RNyR2b0D6GtVZ9FrHG4H\n3EayMsEM4PqIWChpZ+C7wF4ka7KfEhHPFRmLmVkeJfZJfxj4QatChXZ3RMTLwJERcRAwj2TRxUOA\ni4BbI2IusAK4uMg4zMzy6rC7IxdJRwJnMXrl8HEV/isjIl5MX26XthfAScAR6fElwABJ4jYz66lG\nCfiugRe4a+DFcd+bCEkHAIuA4yLiD63KF56kJU0D7gb2Aa6IiJWSZkXEMEBErJO0W9Fx2GSyZUTS\np/lcKS1+rvBRRuVfE0ye6+pjPiu7VFejPul5C3Zk3oIdX91ftHB9oyoarhYuaU/gBuD0iHgsTzxl\n3ElvBg6StCPwPUlvZetVcpuMAxzIvO5PNzOb6takG8COg4Ndq/cVtmv73ByrhX8K2AX4F0kCNkTE\nIU3rLHOctKRPAS+SdJgviIhhSbOBH0fEW8Yp73HS1kJZ/38LX280o8xnFybHdc2f39e1cdI/aZ4z\nX3WEflnKQrSFfnEoaVdJO6WvXwu8C3gQWAacmRY7A1haZBxmZnmV8cXhRBTd3bE7sCTtl54GfDci\nbpZ0B3CdpLOBtcApBcdhZpbLlJq7I33c8eBxjj8LHDOx2qbK5DFltlX1+PKcd2GX2qrSZ9HONbXb\n1mT8WXWmanN3VCsaM7Me81SlZmYVVrUk7VnwzKz2ujkL3nXxvlxlT9GN1RndIWl7SZ+S9M10f19J\n7y02NDOz8lVtdEfeIXiLgZeBt6f7gyTT7JmZTSpVS9J5+6T3iYj3SzoVkvk40qdlzMwmlboOwXsl\nfRglACTtQ3JnbWY2qdR1CN5ngB8Cb5R0NXA4W54YNDObNKo2uiNXko6IH0m6BziM5GH/CyKi4RRQ\nZmZ1VcskLemvgBUR8f/S/ddLOjkivl9odGZmJXuZbXsdwih5R3d8Jru8VUT8EQ9gNrNJaBMzcm1l\nyZukxytXrd51M7Mu6GQInqQrJQ1Luq9R/ZK+KulRSaskzWsVT95Ee5ekLwFXpPvnkqy2UqKqTx5T\nx7aqHl+ZbdU9vjLbqsNn0b4O+6QXA18Dvj3em5KOJxnSvK+kQ4Gvk3zX11DeO+mPAq+QrPD9XZLh\nd+fmPNfMrDY2Mj3XNp6IuB1otm7hSaQJPCLuBHaSNKtZPHlHd7yAF4o1symg4P7mPuDJzP5gemy4\n0Qm5JliS9Abg48BbgdeMHI+Io9qNNA9PsGRmeXRzgqVPxSfHfW/NwFrWDqx9df+2hbeP256kvYAb\nI+KAcd67EfhCRPw83b8V+HhE3NMopry/Mq4m6eZ4L/B3JEte/S7nuWZmtfFKgyF4cxbsy5wF+766\nf9vC29upfhB4Y2Z/j/RYQ3n7pP8sIq4kWdn2JxFxNpD7LlrSNEn3SFqW7u8sabmkhyXdMrIOoplZ\nr3XSJ50SjVf4XQZ8CEDSYcAfI6JhVwfkT9Ib0n+flvQeSQeRLEue1wXAA5n9i4BbI2IusAK4eAJ1\nmZkVppNx0pKuAX4O7CfpCUlnSfqIpHMAIuJm4LeSfgN8A/ifreLJ293x+fRu92Mkw0t2pPE4nLFB\n7wGcAFzClkXOTgKOSF8vAQbwF5NmVgGdDMGLiNNylDlvInXmHd1xU/ryOeDIiTRAMqjxH4Bsl8as\nkVv8iFgnabcJ1mlT2pYvuz/N50pp8XOFf4Fd/jXB5LmuPuazskt1VW3ujrwrs+wt6UZJ6yU9I2mp\npL1znPceYDgiVtG4jwayP0kzsx7qQp90V+Xt7riG5GnDv0r3PwB8Bzi0xXmHAydKOgF4LTBT0lXA\nOkmzImJY0mzgmcZVDGRe96ebmU11a9INYMfBpgMkJuQVtutaXd2Qd5z0fWPH/En6VUQcmLsh6Qjg\nYxFxoqT/Dfw+Ii6T9Alg54jYqk/a46SttbL+CCtzIaIy/7CcHNc1f35f18ZJnx6LcpW9SueUshBt\n3jvpH0i6CLiW5JN+P3CzpF0AIuLZCbZ7KXCdpLOBtcApEzzfzKwQVeuTzpukR5LoOem/I789PkCS\ntFv2T0fET4CfpK+fBY7JH6aZWTlqtcahpPnAkxHxpnT/DOBvSLqCPtvGHXQHpsoMX2W2VfX48px3\n4TjHqhRfO221c03ttjUZf1adqdoah61Gd3yDZPY7JL0T+ALJuObngHwdN2ZmNdLJfNJFaPrFYfbL\nQUlXAL+LiM+m+6siouWE1R0F5y8OzSyHbk6w9L64LlfZG3VKJb44nC5pRkRsBI5mS590nnPNzGrn\n5YoNwWuVaL8D/ETSeuBPwE8BJL2ZpMvDzGxSqdXojoi4RNJ/ALsDy2NL38g0ktVazMwmlVolaYCI\nuGOcY48UE46ZWW9VbQhe3qlKzcymhA6nKj1O0kOSHkmfph77/o6SlqUrha+WdGarePzln5lZRrvd\nHZKmAZeTDLIYAlZKWhoRD2WKnQvcn06PsSvwsKT/mw7OGJeTtJlZRgd90ocAj0bEWgBJ15LMnZ9N\n0gHMTF/PJJnDqGGCBidpM7NRXm6wxmEOY1cCf4okcWddDiyTNATsQDIPUlNO0mZmGY36m18YuIsX\nB+7qtPpjgXsj4ihJ+wA/knRARDzf6AQnaTOzjEbdHa9ZcCivWbBlCv31C7eaGWMQ2DOzP95K4GeR\nTK9BRDwm6bfA/kDD7F+jJF31yWPq2FbV4yuzrbrHV2Zbdfgs2tdBn/RK4M2S9gKeJpkl9NQxZdaS\nzAD6M0mzgP2Ax5tVWqMkbWZWvHbHSUfEJknnActJhjdfGREPSvpI8nYsAj4P/Juk+9LTPt5qNlEn\naTOzjE6mKo2IHwJzxxz7Rub10yT90rnlWj6rVzwLnpnl0c1Z8HaPpr0Pr3pae1diFjwzsynllc1t\nD8ErROFJWtIakhnzNgMbIuIQSTsD3wX2Ilnl5ZSI8Kx6ZtZzGzdOvbk7NgMLIuKgiBgZ2H0RcGtE\nzAVWABeXEIeZWUubNs7ItZWljJbE1r8MTgKOSF8vAQZIEreZWU9tqtiddBlJOkieqtkEfCMi/hWY\nFRHDABGxTtJuJcRhZtbSVEzSh0fE05LeACyX9DBJ4s6q7hATM5tSNm6YYkk6HRdIRPxO0vdJJhwZ\nljQrIoYlzQaeaVzDQOZ1f7qZma1JNxgcnNms4IRs3lStQW+FRiNpe2BaRDwv6XXAu4GFwDLgTOAy\n4AxgaeNaFhQZopnVVj8jN219fXMYGrqpO9W+NLWG4M0Cvpc8lMIM4OqIWC7pLuA6SWeTPMt+SsFx\nmJnls7Hw51MmpNAkHRG/BeaNc/xZkklGzMyqpekU/OWrVudLU1Nlhq8y26p6fGW2Vff4ymyrDp9F\nB5ykzcwqrGJJ2hMsmVntdXOCJe7ImRMP01btSToO+Ge2TFV62ThtLCD5c2Ab4HcRcWSzZnwnbWaW\n9XJ7p+VZLVzSTsAVwLsjYjBdMbwpJ2kzs6z2uzvyrBZ+GnBDRAwCRMT6VpWWMcGSmVl9bMy5bW28\n1cL7xpTZD9hF0o8lrZR0eqtwfCdtZpZV7BeHM4CDgaOA1wG/kPSLiPhNsxPMzGxEoyS9egB+PdDs\nzDyrhT8FrI+Il4CXJN0GHAg4SZuZ5dIoSb9lQbKNuHbh2BJ5VgtfCnxN0nRgO+BQ4EvNwnGSNjPL\n2tDeaXlWC4+IhyTdAtwHbAIWRcQDzep1kjYzy2pzCB60Xi083f8i8MW8dTpJm5llVeyJQydpM7Ms\nJ+l2TZXJY8psq+rxldlW3eMrs606fBYdcJI2M6swJ2kzswqrWJL2LHhmVntdnQXv0pw58aKtZ8Er\ngu+kzcyyOhiCV4TCJ1iStJOkf5f0oKT7JR0qaWdJyyU9LOmWdPo+M7Pea3+CpUKUMQveV4CbI+It\nJM+oPwRcBNwaEXOBFcDFJcRhZtbaVErSknYE/jIiFgNExMaIeI5kjtUlabElwMlFxmFmltuGnFtJ\nir6TfhOwXtJiSfdIWiRpe2BWRAwDRMQ6YLeC4zAzy2dTzq0kRX9xODJ36rkRcZekL5N0dYz9+rTJ\n16kDmdf96WZmtibdYHBwZveqrdgQvKKT9FPAkxFxV7p/A0mSHpY0KyKGJc0GnmlcxYKCQzSzeupn\n5Katr28OQ0M3dafaiiXpQrs70i6NJyXtlx46GrgfWAacmR47g2SOVTOz3nsp51aSMkZ3nA9cLWkV\nyeiO/wVcBrxL0sMkifvSEuIwM2utg9Edko6T9JCkRyR9olETkuZL2iDpr1uFU/jDLBHxK2D+OG8d\nM7GapsrkMWW2VfX4ymyr7vGV2VYdPosOtNndIWkacDnJjecQsFLS0oh4aJxylwK35KnXq4WbmWW1\nPwTvEODRiFgbERuAa0mGG4/1UeB6mn4Xt4WTtJlZVvtD8PqAJzP7T6XHXiVpDnByRPwfINe8H55g\nycxqr6sTLL2vQU5cPwC/H9iy/8jCUe1J+hvg2Ig4J93/78AhEXF+psx1wBcj4peSFgM3RcQNzWLy\nBEtmZlmN+qRfvyDZRjyy1Wrhg8Cemf090mNZbwOulSRgV+B4SRsiYlmjcJykzcyy2h9etxJ4s6S9\ngKeBDwCnZgtExN4jr9M76RubJWhwkjYzG63N0R0RsUnSecByku/7royIByV9JHk7Fo09JU+9TtJm\nZlkdPHEYET8E5o459o0GZc/OU6eTtJlZVokz3OXhJG1mllXiDHd5OEmbmWVVbIIlJ2kzsywnaTOz\nCitxhrs8nKTNzLJ8J92uqTLDV5ltVT2+Mtuqe3xltlWHz6IDTtJmZhVWsSF4nmDJzGqvqxMs7Zwz\nJ/5BHbeXh++kzcyy3N1hZlZhf+p1AKMVOum/pP0k3SvpnvTf5ySdL2lnScslPSzpFkk7FRmHmVlu\n7U/6X4iiVwt/JCIOioiDgT8HXgC+B1wE3BoRc4EVwMVFxmFmllvk3EpS5vJZxwCPRcSTJOt+LUmP\nLwFOLjEOM7NCtFotXNJpkn6VbrdL+q+t6iwzSb8fuCZ9PSsihgEiYh2wW4lxmJl1XWa18GOBtwKn\nStp/TLHHgXdGxIHA54Fvtqq3lC8OJW0DnAiM/GYZ+8dCkz8eBjKv+9PNzGxNusHg4MxeBjLi1dXC\nASSNrBb+0EiBiLgjU/4OxixUO56yRnccD9wdEevT/WFJsyJiWNJsmi5tvqD46MyshvoZuWnr65vD\n0NBNXaq37adZxlst/JAm5T8M/KBVpWUl6VOB72T2lwFnApcBZwBLS4rDzKyFRmPwfgrc3pUWJB0J\nnAW8o1XZwpO0pO1JvjQ8J3P4MuA6SWcDa4FTio7DzCyfRk+zvD3dRlw6tkCe1cKRdACwCDguIv7Q\nKprCk3REvAi8YcyxZ0kS9wRMlcljymyr6vGV2Vbd4yuzrTp8Fp1ou7uj5WrhkvYEbgBOj4jH8lTq\nJw7NzEZpL0nnXC38U8AuwL9IErAhIpr1WztJm5mN1v7kHa1WC4+IvwX+diJ1ehY8M6u9rs6CxyM5\nS+/nWfDMzMpXrWnwnKTNzEap1jR4TtJmZqNUa2mWMufuaNOaXgdQkDW9DqAAa3odQEHW9DqAgqzp\ndQAVtTHnVg4n6Z5Z0+sACrCm1wEUZE2vAyjIml4HUFEbcm7lcHeHmdko/uJwQmbP3oE5c3bvdRhd\nNzQ0+a5rMl4T+LrqYP/9d2Xlym7VVq0+6RqMkzYzy6c746SX5Sx9osdJl/EBmJmN9mKvAxil0kna\nzKx87pM2M6uwavVJO0mbmY1SrTvpSo+TbrXybh1I2kPSCkn3S1ot6fz0+M6Slkt6WNItknbqdawT\nJWmapHskLUv3J8M17STp3yU9mP7MDp0k1/X3kn4t6T5JV0vadjJcVzHaHyedJ2dJ+qqkRyWtkjSv\nVTSVTdI5V96tg43AhRHxVpJlHc5Nr+Mi4NaImAusAC7uYYztugB4ILM/Ga7pK8DNEfEW4ECSRURr\nfV2S5gAfBQ6OiANI/oI+lZpfV3Hae+IwT86SdDywT0TsC3wE+HqraCqbpMmsvBsRG4CRlXdrJSLW\nRcSq9PXzwIMky+qcBCxJiy0BTu5NhO2RtAdwAvCvmcN1v6Ydgb+MiMUAEbExIp6j5teVmg68TtIM\n4LUkyzpNhusqQNt30nly1knAtwEi4k5gJ0mzmkVT5SQ93sq7LZc/rzJJ/cA8kqXcZ0XEMCSJHNit\nd5G15cvAPwDZsex1v6Y3AeslLU67cRala3TW+roiYgj4J+AJkuT8XETcSs2vqzh/yrltJU/OGltm\ncJwyo1Q5SU8qknYArgcuSO+oxz6oU5sHdyS9BxhO/0JoNpa9NteUmgEcDFwREQcDL5B0CdT2ZwUg\n6fUkd3B7AXNI7qg/SM2vqzjVmmCpyqM7cq28Wwfpn5jXA1dFxNL08LCkWRExLGk28EzvIpyww4ET\nJZ1A8qfzTElXAetqfE2Q3Pk8GRF3pfs3kCTpOv+sIFn0+fF0AWgkfQ/4C+p/XUVYC5/dK2fZ4TH7\neXLWIPDGFmVGqfKd9Ksr70ralmTl3bzPa1bNt4AHIuIrmWPLgDPT12cAS8eeVFUR8cmI2DMi9ib5\nuayIiNOBG6npNQGkf/o/KWm/9NDRwP3U+GeVegI4TNJr0sVPjyb5wrfu19V1EdEfEcq5zR5zep6c\ntQz4EICkw4A/jnQ5NVL1uTuOI/m2fWTl3Ut7HNKESTocuA1YTfLnZACfBH4JXEfyW3UtcEpE/LFX\ncbZL0hHAxyLiREm7UPNrknQgyZeh2wCPA2eRfOlW9+v6DEnS2ADcC3wYmEnNr6tqxstZY1YLR9Ll\nwHEk3WlnRcQ9TeuscpI2M5vqqtzdYWY25TlJm5lVmJO0mVmFOUmbmVWYk7SZWYU5SZuZVViVnzi0\nKSAdW/0fJOPHdwc2kTz5JuCFiHhHD8Mz6zmPk7bKkPRp4PmI+FKvYzGrCnd3WJWMmqxJ0n+m/x4h\naUDS9yX9RtIXJJ0m6U5Jv5L0prTcrpKuT4/fKekvenERZt3kJG1Vlv0z7wDgHOC/AKcD+0bEocCV\nJBPaQ/I47pfS4/+N0XNdm9WS+6StLlZGxDMAkh4DlqfHVwML0tfHAG9JJxEC2EHS9hHxYqmRmnWR\nk7TVxcuZ15sz+5vZ8v9YwKHpqhhmk4K7O6zKmi0oMJ7lJOsuJicnM9qZ1ZqTtFVZo6FHjY5fALwt\n/TLx1yQLfZrVmofgmZlVmO+kzcwqzEnazKzCnKTNzCrMSdrMrMKcpM3MKsxJ2syswpykzcwq7P8D\nYa5V2dh0pRgAAAAASUVORK5CYII=\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x10cd979d0>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "conn = connectivity.Connectivity(load_default=True)\n",
    "nnode = conn.weights.shape[0]\n",
    "\n",
    "def make_train(node_idx, node_weights, **params):\n",
    "    weighting = np.zeros(nnode)\n",
    "    weighting[node_idx] = node_weights\n",
    "    eqn_t = equations.PulseTrain()\n",
    "    eqn_t.parameters.update(params)\n",
    "    stimulus = patterns.StimuliRegion(\n",
    "        temporal=eqn_t,\n",
    "        connectivity=conn,\n",
    "        weight=weighting)\n",
    "    return stimulus\n",
    "\n",
    "train1 = make_train([10, 20], 1.0, onset=1.5e3, T=100.0, tau=50.0)\n",
    "train2 = make_train([30, 40], 2.0, onset=1.5e3, T=200.0, tau=100.0)\n",
    "train3 = make_train(r_[7:74:5], 0.2, onset=5e2, T=50.0, tau=20.0)\n",
    "stimulus = MultiStimuliRegion(train1, train2, train3)\n",
    "stimulus.configure_space()\n",
    "time = r_[1e3:2e3:10.0]\n",
    "stimulus.configure_time(time)\n",
    "pattern = stimulus()\n",
    "imshow(pattern, interpolation='none')\n",
    "xlabel('Time')\n",
    "ylabel('Space')\n",
    "colorbar()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Here we just visualize the output of `stimulus`, but it could also be passed to a simulator object for simulation."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 2",
   "language": "python",
   "name": "python2"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.11"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 0
}
